@@ -73,7 +73,7 @@ let shorten maxlen s =
   if len > maxlen then
     (String.sub s 0 (maxlen-3)) ^ "..."
   else if s = "" then
-      "http://www.mldonkey.org/"
+      "http://mldonkey.sf.net/"
   else s
 
 let state_pix state =
