@@ -39,7 +39,6 @@ module type Base = sig
   end
   
 module Base16 = struct 
-    open Misc
     
     let hexa_digit x =
       if x >= 10 then Char.chr (Char.code 'A' + x - 10)
@@ -469,12 +468,10 @@ module Tiger = Make(struct
         "tiger_unsafe_string"
         
       let unsafe_file digest filename = 
-        Printf2.lprintf "Tiger.unsafe_file not implemented\n";
-        exit 70
+        failwith "Tiger.unsafe_file not implemented"
         
-      let digest_subfile digest fd pos len = 
-        Printf2.lprintf "Tiger.digest_subfile not implemented\n";
-        exit 70
+      let digest_subfile _ _ _ _ = 
+        failwith "Tiger.digest_subfile not implemented"
     
       module Base = Base32
         
